====
kgym
====


.. image:: https://img.shields.io/pypi/v/kgym.svg
        :target: https://pypi.python.org/pypi/kgym

.. image:: https://img.shields.io/travis/sebimarkgraf/kgym.svg
        :target: https://travis-ci.org/sebimarkgraf/kgym

.. image:: https://readthedocs.org/projects/kgym/badge/?version=latest
        :target: https://kgym.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Implementations for the OpenAI Gym of Kaggle Environments


* Free software: Apache Software License 2.0
* Documentation: https://kgym.readthedocs.io.


Features
--------

Implementations for the following environments

+-------------+------------+------------+
| Environment | Identifier | Done       |
+=============+============+============+
| ConnectX    | connectx   | X          |
+-------------+------------+------------+
| Tic Tac Toe | tictactoe  |            |
+-------------+------------+------------+
| Identity    | identity   |            |
+-------------+------------+------------+

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
